@@ -1,6 +1,9 @@
+pub mod conn_bridge;
 pub mod conn_pipe;
 pub mod conn_udp;
 
+#[cfg(test)]
+mod conn_bridge_test;
 #[cfg(test)]
 mod conn_pipe_test;
 #[cfg(test)]
